#%%
import sys 
import os
import pytest
sys.path.append(os.path.join(os.path.dirname(os.path.realpath(__file__)), os.pardir))
import mapsud
from mapsud.graph import trajet_optimal_min, trajet_optimal

#%%
#On test les cas particuliers

def test_traj1():
    assert trajet_optimal_min(41,42) == -1 

   
def test_traj2():
    assert trajet_optimal(41,42) == -1




from setuptools import setup, find_packages
import os
import mapsud

setup(name = 'mapsud',
      version = '1.0.2',
      url='https://github.com/lucea97217/mapsud.git',
      author = 'LUCEA, VALDEYRON, YUAN',
      author_email = 'lenny.lucea@etu.umontpellier.fr',
      maintainer = 'LUCEA, VALDEYRON, YUAN',
      maintainer_email = 'lenny.lucea@etu.umontpellier.fr',
      keywords = 'Tarifs autoroutiers sud France',
      packages = ['mapsud','test'],
      description = 'voir presentation',
      long_description = open(os.path.join(os.path.dirname(__file__), 'README.txt')).read(),
      license = 'MIT',
      platforms = 'ALL',
     )